import os

def template_from_stp(path):
    """create template from StripTool .stp file

    """
    template = {}
    template['window-title'] = os.path.basename(os.path.splitext(path)[0])

    curves = {}
    colors = []

    with open(path, 'r') as f:

        for line in f.readlines():
            try:
                key, val = line.strip().split(None, 1)
            except ValueError:
                key = line.strip()
                val = None

            if key == 'Strip.Time.Timespan':
                template['time-window'] = float(val)

            elif key == 'Strip.Color.Background':
                bgcolor = [int(v)/256 for v in val.split()]
                if bgcolor == [255, 255, 255]:
                    template['black-on-white'] = True
                else:
                    template['black-on-white'] = False

            elif 'Strip.Curve.' in key:
                curve, field = key.split('.')[2:4]
                curve = int(curve)
                if curve not in curves:
                    curves[curve] = {}
                curves[curve][field] = val

            elif 'Strip.Color.Color' in key:
                color = [int(v)/256 for v in val.split()]
                colors.append(color)

    channels = {}
    for k, v in sorted(curves.items()):
        if 'Name' not in v:
            continue
        channel = v['Name']
        color = colors[k]
        ymin = float(v['Min'])
        ymax = float(v['Max'])
        scale = 2.0 / (ymax - ymin)
        offset = abs((ymax + ymin) * scale / 2.0)
        channels[channel] = {
            'color': color,
            'scale': scale,
            'offset': offset
        }

    template['plots'] = [
        {
            'channels': channels,
            'row': 0,
            'col': 0,
            'yrange': [-1, 1],
        }
    ]

    return template
